@@ -7,10 +7,26 @@ from qtpy import QtCore, QtGui, QtWidgets
 
 from . import utils
 from .box import CollapsibleBox
+from .rediotab import RadioTabWidget
 from .scrollarea import VerticalScrollArea
 from .widgets import ParameterWidget, BoolParameter
 
 
+class Separator(QtWidgets.QWidget):
+    def __init__(self, parent: QtWidgets.QWidget | None = None) -> None:
+        super().__init__(parent)
+
+        layout = QtWidgets.QVBoxLayout()
+        layout.setContentsMargins(QtCore.QMargins(0, 9, 0, 9))
+        self.setLayout(layout)
+
+        frame = QtWidgets.QFrame(self)
+        frame.setFixedHeight(1)
+        frame.setFrameShape(QtWidgets.QFrame.Shape.StyledPanel)
+        frame.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
+        layout.addWidget(frame)
+
+
 class ParameterToolTip(QtWidgets.QFrame):
     def __init__(
         self, widget: ParameterWidget, parent: QtWidgets.QWidget | None = None
@@ -86,6 +102,26 @@ class ParameterLabel(QtWidgets.QLabel):
             self._tooltip.show()
 
 
+class LabelFilter(QtCore.QObject):
+    def __init__(
+        self, label: QtWidgets.QLabel, parent: QtWidgets.QWidget | None = None
+    ) -> None:
+        if not parent:
+            # Store the LabelFilter on the label, as it should be deleted with the
+            # label and not the watched widget.
+            parent = label
+        super().__init__(parent)
+        self.label = label
+
+    def eventFilter(self, watched: QtCore.QObject, event: QtCore.QEvent) -> bool:
+        if isinstance(watched, QtWidgets.QWidget):
+            if event.type() == QtCore.QEvent.Type.EnabledChange:
+                self.label.setEnabled(watched.isEnabled())
+            elif event.type() in (QtCore.QEvent.Type.Show, QtCore.QEvent.Type.Hide):
+                self.label.setVisible(watched.isVisible())
+        return False
+
+
 class ParameterForm(QtWidgets.QWidget):
     parameter_changed: QtCore.Signal = QtCore.Signal(ParameterWidget)
 
@@ -171,6 +207,9 @@ class ParameterForm(QtWidgets.QWidget):
                 values[name] = widget.values()
             elif isinstance(widget, CollapsibleBox):
                 values[name] = widget.checked()
+            elif isinstance(widget, RadioTabWidget):
+                if form := self.form(name.replace('_enabled', '')):
+                    values[name] = widget.currentWidget() == form
         return values
 
     def set_values(self, values: dict) -> None:
@@ -185,6 +224,10 @@ class ParameterForm(QtWidgets.QWidget):
                 widget.set_values(value)
             elif isinstance(widget, CollapsibleBox):
                 widget.set_checked(value)
+            elif isinstance(widget, RadioTabWidget):
+                if value:
+                    if form := self.form(name.replace('_enabled', '')):
+                        widget.setCurrentWidget(form)
 
     def set_defaults(self, values: dict) -> None:
         """Set the default values of ParameterWidgets in the form."""
@@ -242,9 +285,11 @@ class ParameterForm(QtWidgets.QWidget):
             label = ParameterLabel(widget, self)
             label.setEnabled(widget.isEnabled())
             self._layout.addWidget(label, row, 1)
-            widget.enabled_changed.connect(label.setEnabled)
             if alignment:
                 label.setAlignment(alignment)
+            label.setVisible(False)
+            label_filter = LabelFilter(label)
+            widget.installEventFilter(label_filter)
 
         # Widget
         self._layout.addWidget(widget, row, 2)
@@ -281,14 +326,23 @@ class ParameterForm(QtWidgets.QWidget):
 
         return box
 
-    def add_forms(self, forms: Sequence[ParameterForm]) -> QtWidgets.QTabWidget:
-        """Add multiple forms and return the TabWidget."""
+    def add_forms(
+        self, forms: Sequence[ParameterForm], radio: bool = False
+    ) -> QtWidgets.QTabWidget:
+        """
+        Add multiple forms and return the TabWidget. If radio is True, use a
+        RadioTabWidget which only allows one form to be active.
+        """
 
         # Validate the names before creating any widgets.
         for form in forms:
             self._validate_name(form.name())
 
-        tab_widget = QtWidgets.QTabWidget()
+        if radio:
+            tab_widget = RadioTabWidget()
+        else:
+            tab_widget = QtWidgets.QTabWidget()
+
         for form in forms:
             name = form.name()
             self._widgets[name] = form
@@ -298,6 +352,9 @@ class ParameterForm(QtWidgets.QWidget):
             label = utils.title(name)
             tab_widget.addTab(form, label)
 
+            if radio:
+                self._widgets[f'{name}_enabled'] = tab_widget
+
         self.add_widget(tab_widget)
 
         return tab_widget
@@ -324,11 +381,11 @@ class ParameterForm(QtWidgets.QWidget):
     def add_separator(
         self,
         name: str = '',
-        column: int = 1,
+        column: int = 2,
         column_span: int = -1,
         row: int = -1,
         row_span: int = 1,
-    ) -> QtWidgets.QFrame:
+    ) -> Separator:
         """Add a horizontal separator to the ParameterForm's GridLayout."""
 
         if row < 0:
@@ -336,12 +393,10 @@ class ParameterForm(QtWidgets.QWidget):
         if name:
             label = QtWidgets.QLabel(name)
             self._layout.addWidget(label, row, 1)
-        line = QtWidgets.QFrame(self)
-        line.setFixedHeight(1)
-        line.setFrameShape(QtWidgets.QFrame.Shape.StyledPanel)
-        line.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
-        self.add_widget(line, column, column_span, row, row_span)
-        return line
+            column = min(2, column)
+        separator = Separator()
+        self.add_widget(separator, column, column_span, row, row_span)
+        return separator
 
     def add_layout(
         self,
@@ -489,6 +544,8 @@ class ParameterForm(QtWidgets.QWidget):
                 widgets[name] = widget
             elif isinstance(widget, CollapsibleBox):
                 widgets[name] = widget
+            elif isinstance(widget, RadioTabWidget):
+                widgets[name] = widget
         return widgets
 
     @staticmethod
